@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/procmeter3/gtk1/RCS/window.c 1.7 2007/11/24 16:02:27 amb Exp $
-
-  ProcMeter - A system monitoring program for Linux - Version 3.5a.
+  ProcMeter - A system monitoring program for Linux - Version 3.6.
 
   X Windows interface.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1997,98,99,2000,01,02,04,07 Andrew M. Bishop
+  This file Copyright 1997-2012 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -20,6 +18,8 @@
 
 #include <sys/time.h>
 
+#include <X11/Xlib.h>
+#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 #include "widgets/PMGeneric.h"
@@ -38,6 +38,7 @@
 static gint SleepCallback(gpointer p);
 static void ResizePaneCallback(GtkWidget *w,GdkEventConfigure *event);
 static gint CloseCallback(GtkWidget *w,GdkEvent *event,gpointer data);
+static void add_EWMH(char *name);
 
 
 /*+ The toplevel widget. +*/
@@ -75,8 +76,7 @@ void Start(int *argc,char **argv)
 {
  static char procmeter_version[]="ProcMeter V" PROCMETER_VERSION;
  char *string;
- GtkWidget *event_box;
- int i;
+ int i,j=0;
 
  if((string=GetProcMeterRC("resources","horizontal")) &&
     StringToBoolean(string))
@@ -90,20 +90,12 @@ void Start(int *argc,char **argv)
  gtk_window_set_title(GTK_WINDOW(toplevel),procmeter_version);
  gtk_window_set_policy(GTK_WINDOW(toplevel),TRUE,TRUE,TRUE);
 
- /* Create the bitmaps */
-
- CreateBitmaps(toplevel);
-
  /* Create the menu widgets */
 
  CreateMenus(toplevel);
 
  /* Create the pane widget */
 
- event_box=gtk_event_box_new();
- gtk_container_add(GTK_CONTAINER(toplevel),event_box);
- gtk_widget_show(event_box);
-
  if(vertical)
     pane=gtk_vbox_new(FALSE,0);
  else
@@ -111,22 +103,28 @@ void Start(int *argc,char **argv)
 
  gtk_box_set_spacing(GTK_BOX(pane),2);
 
- gtk_container_add(GTK_CONTAINER(event_box),pane);
+ gtk_container_add(GTK_CONTAINER(toplevel),pane);
  gtk_widget_show(GTK_WIDGET(pane));
 
  gtk_signal_connect(GTK_OBJECT(toplevel),"configure_event",
                     GTK_SIGNAL_FUNC(ResizePaneCallback),NULL);
 
- AddMenuToOutput(event_box,NULL);
+ AddMenuToOutput(pane,NULL);
 
- /* Parse the -geometry flag */
+ /* Show the widgets */
 
- for(i=1;i<*argc-1;i++)
-    if(!strcmp(argv[i],"-geometry"))
+ gtk_widget_show(GTK_WIDGET(toplevel));
+
+ /* Parse the -geometry and -w flag */
+
+ for(i=1;i<*argc;i++)
+    if((!strcmp(argv[i],"-geometry")) && (i+1<=*argc))
       {
        int x,y,w,h;
 
-       if(sscanf(argv[i+1],"%dx%d%d%d",&w,&h,&x,&y)==4)
+       i++;j+=2;
+
+       if(sscanf(argv[i],"%dx%d%d%d",&w,&h,&x,&y)==4)
          {
           gtk_widget_set_usize(GTK_WIDGET(toplevel),w,h);
 
@@ -134,28 +132,45 @@ void Start(int *argc,char **argv)
           if(y<0) y=gdk_screen_height()-h+y;
 
           gtk_widget_set_uposition(GTK_WIDGET(toplevel),x,y);
-
-          break;
          }
-       else if(sscanf(argv[i+1],"%dx%d",&w,&h)==2)
-         {
+       else if(sscanf(argv[i],"%dx%d",&w,&h)==2)
           gtk_widget_set_usize(GTK_WIDGET(toplevel),w,h);
+       else
+          fprintf(stderr,"ProcMeter: Cannot parse -geometry option: '%s'\n",argv[i]);
+      }
+    else if((!strcmp(argv[i],"-w")) && (i+1<=*argc))
+      {
+       char *token;
 
-          break;
+       i++;j+=2;
+
+       token=strtok(argv[i],",");
+       while(token)
+         {
+          if(!strcmp(token,"above"))
+             add_EWMH("_NET_WM_STATE_ABOVE");
+          else if(!strcmp(token,"below"))
+             add_EWMH("_NET_WM_STATE_BELOW");
+          else if(!strcmp(token,"skip_taskbar"))
+             add_EWMH("_NET_WM_STATE_SKIP_TASKBAR");
+          else if(!strcmp(token,"skip_pager"))
+             add_EWMH("_NET_WM_STATE_SKIP_PAGER");
+          else if(!strcmp(token,"sticky"))
+             add_EWMH("_NET_WM_STATE_STICKY");
+          else
+             fprintf(stderr,"ProcMeter: Cannot parse -w option: '%s'\n",token);
+
+          token = strtok(NULL,",");
          }
       }
 
- if(i<*argc-1)
+ if(j>0)
    {
-    for(i+=2;i<*argc;i++)
-       argv[i-2]=argv[i];
-    *argc-=2;
+    for(i=j;i<*argc;i++)
+      argv[i-j]=argv[i];
+    *argc-=j;
    }
 
- /* Show the widgets */
-
- gtk_widget_show(GTK_WIDGET(toplevel));
-
  /* Put an action on the window manager close button */
 
  gtk_signal_connect(GTK_OBJECT(toplevel),"delete_event",
@@ -490,7 +505,7 @@ void MoveOutput(Output output1,Output output2,int direction)
 
 void Resize(void)
 {
- gushort psize,size;
+ gushort psize;
  gint width,height;
  int gsize,msize;
  int i,ngraphs=0;
@@ -551,33 +566,33 @@ void Resize(void)
     return;
    }
 
- for(i=0;i<ndisplayed;i++)
-   {
-    if(displayed[i]->type==PROCMETER_GRAPH || displayed[i]->type==PROCMETER_BAR)
-      {
-       size=gsize/ngraphs;
-       gsize-=size;
-       ngraphs--;
-
-       if(vertical)
-          height=size;
-       else
-          width=size;
-      }
-    else
-      {
-       GtkRequisition request;
-
-       gtk_widget_size_request(GTK_WIDGET(displayed[i]->output_widget),&request);
-
-       if(vertical)
-          height=request.height;
-       else
-          width=request.width;
-      }
-
-    //gtk_widget_set_usize(GTK_WIDGET(displayed[i]->output_widget),width,height);
-   }
+// for(i=0;i<ndisplayed;i++)
+//   {
+//    if(displayed[i]->type==PROCMETER_GRAPH || displayed[i]->type==PROCMETER_BAR)
+//      {
+//       gushort size=gsize/ngraphs;
+//       gsize-=size;
+//       ngraphs--;
+//
+//       if(vertical)
+//          height=size;
+//       else
+//          width=size;
+//      }
+//    else
+//      {
+//       GtkRequisition request;
+//
+//       gtk_widget_size_request(GTK_WIDGET(displayed[i]->output_widget),&request);
+//
+//       if(vertical)
+//          height=request.height;
+//       else
+//          width=request.width;
+//      }
+//
+//    gtk_widget_set_usize(GTK_WIDGET(displayed[i]->output_widget),width,height);
+//   }
 }
 
 
@@ -634,3 +649,30 @@ static gint CloseCallback(GtkWidget *w,GdkEvent *event,gpointer data)
 
  return(TRUE);
 }
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Adds an Extended Window Manager Hint to the window.
+
+  char *name The name of the hint to add.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+static void add_EWMH(char *name)
+{
+ XEvent event;
+ Display *display=GDK_WINDOW_XDISPLAY(toplevel->window);
+
+ event.xclient.type=ClientMessage;
+ event.xclient.serial=0;
+ event.xclient.send_event=True;
+ event.xclient.message_type=XInternAtom(display,"_NET_WM_STATE",False);
+ event.xclient.window=GDK_WINDOW_XWINDOW(GTK_WIDGET(toplevel)->window);
+ event.xclient.format=32;
+ event.xclient.data.l[0]=1; /* add */
+ event.xclient.data.l[1]=XInternAtom(display,name,False);
+ event.xclient.data.l[2]=0;
+ event.xclient.data.l[3]=0;
+ event.xclient.data.l[4]=0;
+
+ XSendEvent(display,DefaultRootWindow(display),False,SubstructureRedirectMask|SubstructureNotifyMask,&event);
+}
