@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/procmeter3/gtk2/RCS/window.c 1.4 2007/11/24 16:02:33 amb Exp $
-
-  ProcMeter - A system monitoring program for Linux - Version 3.5a.
+  ProcMeter - A system monitoring program for Linux - Version 3.6.
 
   X Windows interface.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1997,98,99,2000,01,02,04,07 Andrew M. Bishop
+  This file Copyright 1997-2012 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -75,8 +73,7 @@ void Start(int *argc,char **argv)
 {
  static char procmeter_version[]="ProcMeter V" PROCMETER_VERSION;
  char *string;
- GtkWidget *event_box;
- int i;
+ int i,j=0;
 
  if((string=GetProcMeterRC("resources","horizontal")) &&
     StringToBoolean(string))
@@ -90,9 +87,12 @@ void Start(int *argc,char **argv)
  gtk_window_set_title(GTK_WINDOW(toplevel),procmeter_version);
  gtk_window_set_resizable(GTK_WINDOW(toplevel),TRUE);
 
- /* Create the bitmaps */
+ if((string=GetProcMeterRC("resources","foreground")))
+   {
+    GdkColor color=StringToPixel(string);
 
- CreateBitmaps(toplevel);
+    gtk_widget_modify_bg(GTK_WIDGET(toplevel),GTK_STATE_NORMAL,&color);
+   }
 
  /* Create the menu widgets */
 
@@ -100,10 +100,6 @@ void Start(int *argc,char **argv)
 
  /* Create the pane widget */
 
- event_box=gtk_event_box_new();
- gtk_container_add(GTK_CONTAINER(toplevel),event_box);
- gtk_widget_show(event_box);
-
  if(vertical)
     pane=gtk_vbox_new(FALSE,0);
  else
@@ -111,22 +107,24 @@ void Start(int *argc,char **argv)
 
  gtk_box_set_spacing(GTK_BOX(pane),2);
 
- gtk_container_add(GTK_CONTAINER(event_box),pane);
+ gtk_container_add(GTK_CONTAINER(toplevel),pane);
  gtk_widget_show(GTK_WIDGET(pane));
 
  gtk_signal_connect(GTK_OBJECT(toplevel),"configure_event",
                     GTK_SIGNAL_FUNC(ResizePaneCallback),NULL);
 
- AddMenuToOutput(event_box,NULL);
+ AddMenuToOutput(pane,NULL);
 
- /* Parse the -geometry flag */
+ /* Parse the -geometry and -w flag */
 
- for(i=1;i<*argc-1;i++)
-    if(!strcmp(argv[i],"-geometry"))
+ for(i=1;i<*argc;i++)
+    if((!strcmp(argv[i],"-geometry")) && (i+1<=*argc))
       {
        int x,y,w,h;
 
-       if(sscanf(argv[i+1],"%dx%d%d%d",&w,&h,&x,&y)==4)
+       i++;j+=2;
+
+       if(sscanf(argv[i],"%dx%d%d%d",&w,&h,&x,&y)==4)
          {
           gtk_widget_set_size_request(GTK_WIDGET(toplevel),w,h);
 
@@ -134,22 +132,43 @@ void Start(int *argc,char **argv)
           if(y<0) y=gdk_screen_height()-h+y;
 
           gtk_window_move(GTK_WINDOW(toplevel),x,y);
-
-          break;
          }
-       else if(sscanf(argv[i+1],"%dx%d",&w,&h)==2)
-         {
+       else if(sscanf(argv[i],"%dx%d",&w,&h)==2)
           gtk_widget_set_size_request(GTK_WIDGET(toplevel),w,h);
+       else
+          fprintf(stderr,"ProcMeter: Cannot parse -geometry option: '%s'\n",argv[i]);
+      }
+    else if((!strcmp(argv[i],"-w")) && (i+1<=*argc))
+      {
+       char *token;
 
-          break;
+       i++;j+=2;
+
+       token=strtok(argv[i],",");
+       while(token)
+         {
+          if(!strcmp(token,"above"))
+             gtk_window_set_keep_above(GTK_WINDOW(toplevel),TRUE);
+          else if(!strcmp(token,"below"))
+             gtk_window_set_keep_below(GTK_WINDOW(toplevel),TRUE);
+          else if(!strcmp(token,"skip_taskbar"))
+             gtk_window_set_skip_taskbar_hint(GTK_WINDOW(toplevel),TRUE);
+          else if(!strcmp(token,"skip_pager"))
+             gtk_window_set_skip_pager_hint(GTK_WINDOW(toplevel),TRUE);
+          else if(!strcmp(token,"sticky"))
+             gtk_window_stick(GTK_WINDOW(toplevel));
+          else
+             fprintf(stderr,"ProcMeter: Cannot parse -w option: '%s'\n",token);
+
+          token = strtok(NULL,",");
          }
       }
 
- if(i<*argc-1)
+ if(j>0)
    {
-    for(i+=2;i<*argc;i++)
-       argv[i-2]=argv[i];
-    *argc-=2;
+    for(i=j;i<*argc;i++)
+      argv[i-j]=argv[i];
+    *argc-=j;
    }
 
  /* Show the widgets */
@@ -490,7 +509,7 @@ void MoveOutput(Output output1,Output output2,int direction)
 
 void Resize(void)
 {
- gushort psize,size;
+ gushort psize;
  gint width,height;
  int gsize,msize;
  int i,ngraphs=0;
@@ -552,33 +571,33 @@ void Resize(void)
     return;
    }
 
- for(i=0;i<ndisplayed;i++)
-   {
-    if(displayed[i]->type==PROCMETER_GRAPH || displayed[i]->type==PROCMETER_BAR)
-      {
-       size=gsize/ngraphs;
-       gsize-=size;
-       ngraphs--;
-
-       if(vertical)
-          height=size;
-       else
-          width=size;
-      }
-    else
-      {
-       GtkRequisition request;
-
-       gtk_widget_size_request(GTK_WIDGET(displayed[i]->output_widget),&request);
-
-       if(vertical)
-          height=request.height;
-       else
-          width=request.width;
-      }
-
-    //gtk_widget_set_size_request(GTK_WIDGET(displayed[i]->output_widget),width,height);
-   }
+// for(i=0;i<ndisplayed;i++)
+//   {
+//    if(displayed[i]->type==PROCMETER_GRAPH || displayed[i]->type==PROCMETER_BAR)
+//      {
+//       gushort size=gsize/ngraphs;
+//       gsize-=size;
+//       ngraphs--;
+//
+//       if(vertical)
+//          height=size;
+//       else
+//          width=size;
+//      }
+//    else
+//      {
+//       GtkRequisition request;
+//
+//       gtk_widget_size_request(GTK_WIDGET(displayed[i]->output_widget),&request);
+//
+//       if(vertical)
+//          height=request.height;
+//       else
+//          width=request.width;
+//      }
+//
+//    gtk_widget_set_size_request(GTK_WIDGET(displayed[i]->output_widget),width,height);
+//   }
 
  gtk_container_resize_children(GTK_CONTAINER(pane));
 }
