@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/procmeter3/modules/RCS/acpi.c 1.15 2007/12/15 19:32:53 amb Exp $
-
-  ProcMeter - A system monitoring program for Linux - Version 3.4g.
+  ProcMeter - A system monitoring program for Linux - Version 3.6.
 
   ACPI source file.
   ******************/ /******************
   Written by Joey Hess.
 
-  This file Copyright 2001 Joey Hess
+  This file Copyright 2001-2011 Joey Hess
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -159,20 +157,25 @@ char *get_acpi_value (const char *file, const char *key) {
  */
 int get_acpi_batt_capacity(int battery) {
 	int dcap, lcap;
-	char *dcaps=get_acpi_value(acpi_batt_info[battery], acpi_labels[label_design_capacity]);
-	char *lcaps=get_acpi_value(acpi_batt_info[battery], acpi_labels[label_last_full_capacity]);
-	if (dcaps == NULL)
+	char *s;
+
+	s=get_acpi_value(acpi_batt_info[battery], acpi_labels[label_design_capacity]);
+	if (s == NULL)
 		dcap=0; /* battery not present */
 	else
-		dcap=atoi(dcaps);
+		dcap=atoi(s);
+
 	/* This is ACPI's broken way of saying that there is no battery. */
 	if (dcap == 655350)
 		return 0;
-	if (lcaps != NULL) {
-		lcap=atoi(lcaps);
+
+	s=get_acpi_value(acpi_batt_info[battery], acpi_labels[label_last_full_capacity]);
+	if (s != NULL) {
+		lcap=atoi(s);
 		if (lcap > dcap)
 			return lcap;
 	}
+
 	return dcap;
 }
 
@@ -294,7 +297,7 @@ int acpi_supported (void) {
 	}
 	num = atoi(version);
 	if (num < ACPI_VERSION) {
-		fprintf(stderr, "ACPI subsystem %s too is old, consider upgrading to %i.\n",
+		fprintf(stderr, "ProcMeter(%s): ACPI subsystem %s too is old, consider upgrading to %i.\n",__FILE__,
 				version, ACPI_VERSION);
 		return 0;
 	}
@@ -335,8 +338,7 @@ int acpi_read (int battery, apm_info *info) {
 	
 	buf = get_acpi_file(acpi_batt_status[battery]);
 	if (buf == NULL) {
-		fprintf(stderr, "unable to read %s\n", acpi_batt_status[battery]);
-		perror("read");
+                fprintf(stderr, "ProcMeter(%s): Unable to read %s\n",__FILE__, acpi_batt_status[battery]);
 		exit(1);
 	}
 
@@ -407,7 +409,7 @@ int acpi_read (int battery, apm_info *info) {
 				info->ac_line_status = 1;
 			}
 			else {
-				fprintf(stderr, "unknown battery state: %s\n", state);
+                                fprintf(stderr, "ProcMeter(%s): Unknown battery state: %s\n", __FILE__, state);
 			}
 		}
 		else {
@@ -612,12 +614,11 @@ ProcMeterOutput **Initialise(char *options)
 		 l++;
 
 	 if(*l) {
-		 char *r=l,pr;
+		 char *r=l;
 
 		 while(*r && *r!=' ')
 			 r++;
 
-		 pr=*r;
 		 *r=0;
 
 		 if (strcmp(l, "C") == 0) {
