@@ -1,13 +1,13 @@
 /***************************************
-  $Header: /home/amb/procmeter3/modules/RCS/loadavg.c 1.4 1999/09/29 18:59:59 amb Exp $
+  $Header: /home/amb/CVS/procmeter3/modules/loadavg.c,v 1.8 2010-02-28 10:08:08 amb Exp $
 
-  ProcMeter - A system monitoring program for Linux - Version 3.2.
+  ProcMeter - A system monitoring program for Linux - Version 3.5d.
 
   Load average and number of processes module source file.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1998,99 Andrew M. Bishop
+  This file Copyright 1998-2010 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -24,40 +24,40 @@
 /*+ The load average output +*/
 ProcMeterOutput loadavg_output=
 {
- /* char  name[16];         */ "Load",
- /* char *description;      */ "The system load, a rolling average of the number of processes running.",
- /* char  type;             */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
- /* short interval;         */ 1,
- /* char  text_value[16];   */ "unknown",
- /* long  graph_value;      */ 0,
- /* short graph_scale;      */ 1,
- /* char  graph_units[8];   */ "(%d)"
+ /* char  name[];          */ "Load",
+ /* char *description;     */ "The system load, a rolling average of the number of processes running.",
+ /* char  type;            */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
+ /* short interval;        */ 1,
+ /* char  text_value[];    */ "unknown",
+ /* long  graph_value;     */ 0,
+ /* short graph_scale;     */ 1,
+ /* char  graph_units[];   */ "(%d)"
 };
 
 /*+ The number of processes output. +*/
 ProcMeterOutput processes_output=
 {
- /* char  name[16];         */ "Processes",
- /* char *description;      */ "The number of processes that exist in the system.",
- /* char  type;             */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
- /* short interval;         */ 1,
- /* char  text_value[16];   */ "unknown",
- /* long  graph_value;      */ 0,
- /* short graph_scale;      */ 10,
- /* char  graph_units[8];   */ "(%d)"
+ /* char  name[];          */ "Processes",
+ /* char *description;     */ "The number of processes that exist in the system.",
+ /* char  type;            */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
+ /* short interval;        */ 1,
+ /* char  text_value[];    */ "unknown",
+ /* long  graph_value;     */ 0,
+ /* short graph_scale;     */ 10,
+ /* char  graph_units[];   */ "(%d)"
 };
 
 /*+ The number of forks per second output. +*/
 ProcMeterOutput forks_output=
 {
- /* char  name[16];         */ "Forks",
- /* char *description;      */ "The number of new processes that start per second.",
- /* char  type;             */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
- /* short interval;         */ 1,
- /* char  text_value[16];   */ "unknown",
- /* long  graph_value;      */ 0,
- /* short graph_scale;      */ 5,
- /* char  graph_units[8];   */ "(%d/s)"
+ /* char  name[];          */ "Forks",
+ /* char *description;     */ "The number of new processes that start per second.",
+ /* char  type;            */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
+ /* short interval;        */ 1,
+ /* char  text_value[];    */ "unknown",
+ /* long  graph_value;     */ 0,
+ /* short graph_scale;     */ 5,
+ /* char  graph_units[];   */ "(%d/s)"
 };
 
 /*+ The outputs. +*/
@@ -66,8 +66,8 @@ ProcMeterOutput *outputs[4];
 /*+ The module. +*/
 ProcMeterModule module=
 {
- /* char name[16];          */ "Processes",
- /* char *description;      */ "The load average and the number of processes running and starting. [From /proc/loadavg]",
+ /* char name[];           */ "Processes",
+ /* char *description;     */ "The load average and the number of processes running and starting. [From /proc/loadavg]",
 };
 
 
@@ -94,7 +94,6 @@ ProcMeterModule *Load(void)
 ProcMeterOutput **Initialise(char *options)
 {
  FILE *f;
- char line[80];
  int n;
 
  for(n=0;n<sizeof(outputs)/sizeof(outputs[0]);n++)
@@ -108,7 +107,10 @@ ProcMeterOutput **Initialise(char *options)
     fprintf(stderr,"ProcMeter(%s): Could not open '/proc/loadavg'.\n",__FILE__);
  else
    {
-    if(!fgets(line,80,f))
+    char *line=NULL;
+    size_t length=64;
+
+    if(!fgets_realloc(&line,&length,f))
        fprintf(stderr,"ProcMeter(%s): Could not read '/proc/loadavg'.\n",__FILE__);
     else
       {
@@ -130,6 +132,9 @@ ProcMeterOutput **Initialise(char *options)
        if(forks_available)     outputs[n++]=&forks_output;
       }
 
+    if(line)
+       free(line);
+
     fclose(f);
    }
 
@@ -164,7 +169,8 @@ int Update(time_t now,ProcMeterOutput *output)
     if(!f)
        return(-1);
 
-    fscanf(f,"%f %*f %*f %*d/%ld %ld",&l,&n,&p2);
+    if(fscanf(f,"%f %*f %*f %*d/%ld %ld",&l,&n,&p2)!=3)
+       return(-1);
 
     fclose(f);
 
