@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/procmeter3/RCS/procmeter.h 1.24 2008/05/05 18:45:17 amb Exp $
-
-  ProcMeter - A system monitoring program for Linux - Version 3.5b.
+  ProcMeter - A system monitoring program for Linux - Version 3.6.
 
   Global public header file.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1998-2008 Andrew M. Bishop
+  This file Copyright 1998-2012 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -21,11 +19,11 @@
 #include <stdio.h>
 
 
-#define PROCMETER_VERSION "3.5b"
+#define PROCMETER_VERSION "3.6"
 
 
 #define PROCMETER_MAJOR_VERSION 3
-#define PROCMETER_MINOR_VERSION 5
+#define PROCMETER_MINOR_VERSION 6
 
 
 #define PROCMETER_GRAPH 1
