@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/procmeter3/xaw/RCS/menus.c 1.16 2002/12/07 19:34:32 amb Exp $
-
-  ProcMeter - A system monitoring program for Linux - Version 3.4.
+  ProcMeter - A system monitoring program for Linux - Version 3.6.
 
   X Window menus.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1998,99,2000,01,02 Andrew M. Bishop
+  This file Copyright 1998-2012 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -70,7 +68,8 @@ static Widget func_run;
 static Widget prop_modname,prop_moddesc,
               prop_outname,prop_outdesc,
               prop_label,prop_type,prop_interval,prop_scale;
-static Boolean properties_popped_up=False,doing_move=False;
+static Boolean properties_popped_up=False;
+static int doing_move=0;
 
 XtActionsRec MenuActions[]={{"ModuleMenuStart",ModuleMenuStart},
                             {"OutputMenuStart",OutputMenuStart},
@@ -118,7 +117,11 @@ void CreateMenus(Widget parent)
    {XtSetArg(args[nargs],XtNbackground,StringToPixel(string));nargs++;}
 
  if((string=GetProcMeterRC("resources","menu-font")))
-   {XtSetArg(args[nargs],XtNfont,StringToFont(string));nargs++;}
+   {
+    XFontStruct *font=StringToFont(string);
+    if(font)
+      {XtSetArg(args[nargs],XtNfont,font);nargs++;}
+   }
 
  if(nargs==1)
     resources=XtVaCreateArgsList(NULL,
@@ -153,6 +156,8 @@ void CreateMenus(Widget parent)
                                   XtVaNestedList,resources,
                                   NULL);
 
+ XtSetValues(menuline,args,nargs);
+
  /* The functions menu */
 
  functions_menu=XtVaCreatePopupShell("FunctionsMenu",simpleMenuWidgetClass,parent,
@@ -167,6 +172,8 @@ void CreateMenus(Widget parent)
                                   XtVaNestedList,resources,
                                   NULL);
 
+ XtSetValues(menuline,args,nargs);
+
  /* The functions menu items */
 
  func_prop=XtVaCreateManagedWidget("Properties",smeBSBObjectClass,functions_menu,
@@ -397,7 +404,11 @@ void AddModuleToMenu(Module module)
 
  if(((string=GetProcMeterRC(module->module->name,"menu-font")) ||
      (string=GetProcMeterRC("resources","menu-font"))))
-   {XtSetArg(args[nargs],XtNfont,StringToFont(string));nargs++;}
+   {
+    XFontStruct *font=StringToFont(string);
+    if(font)
+      {XtSetArg(args[nargs],XtNfont,font);nargs++;}
+   }
 
  /* Create a new menu. */
 
@@ -446,7 +457,11 @@ void AddModuleToMenu(Module module)
        if(((string=GetProcMeterRC2(module->module->name,module->outputs[i]->output->name,"menu-font")) ||
            (string=GetProcMeterRC(module->module->name,"menu-font")) ||
            (string=GetProcMeterRC("resources","menu-font"))))
-          XtVaSetValues(menuitem,XtNfont,StringToFont(string),NULL);
+         {
+          XFontStruct *font=StringToFont(string);
+          if(font)
+             XtVaSetValues(menuitem,XtNfont,font,NULL);
+         }
 
        submenu=XtVaCreatePopupShell("Type",simpleMenuWidgetClass,module->submenu_widget,
                                     NULL);
@@ -581,7 +596,7 @@ static void SelectOutputMenuCallback(Widget widget,XtPointer clientData,XtPointe
 
 static void SelectFunctionsMenuCallback(Widget widget,XtPointer clientData,XtPointer callData)
 {
- if((int)clientData==0)         /* Properties */
+ if(clientData==(XtPointer)0)         /* Properties */
    {
     Window root_return, child_return;
     int root_x_return, root_y_return;
@@ -598,17 +613,17 @@ static void SelectFunctionsMenuCallback(Widget widget,XtPointer clientData,XtPoi
     XtPopup(properties_dialog,XtGrabNone);
     properties_popped_up=True;
    }
- else if((int)clientData==1 || (int)clientData==2) /* Above / Below */
+ else if(clientData==(XtPointer)1 || clientData==(XtPointer)2) /* Above / Below */
    {
-    doing_move=(int)clientData;
+    doing_move=(long)clientData;
 
     XtGrabPointer(pane,True,ButtonPressMask|ButtonReleaseMask,GrabModeAsync,GrabModeAsync,None,XCreateFontCursor(XtDisplay(pane),XC_hand1),CurrentTime);
    }
- else if((int)clientData==3)    /* Delete */
+ else if(clientData==(XtPointer)3)    /* Delete */
    {
     AddRemoveOutput(function_output);
    }
- else if((int)clientData==4)    /* Run */
+ else if(clientData==(XtPointer)4)    /* Run */
    {
     if(function_output->menu_run.flag)
        RunProgram(&function_output->menu_run);
