@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/procmeter3/xaw/RCS/window.c 1.11 2000/12/16 16:51:15 amb Exp $
-
-  ProcMeter - A system monitoring program for Linux - Version 3.3.
+  ProcMeter - A system monitoring program for Linux - Version 3.6.
 
   X Windows interface.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1997,98,99,2000 Andrew M. Bishop
+  This file Copyright 1997-2012 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -42,8 +40,8 @@
 
 static void SleepCallback(XtPointer p,XtIntervalId i);
 static void ResizePaneCallback(Widget w,XtPointer va,XEvent* e,Boolean* vb);
-static void ResizePane(void);
 static void CloseCallback(Widget w,XtPointer va,XEvent* e,Boolean* vb);
+static void add_EWMH(char *name);
 
 
 /*+ The application context. +*/
@@ -52,6 +50,9 @@ XtAppContext app_context;
 /*+ The display that the meter is on. +*/
 Display* display=NULL;
 
+/*+ The toplevel widget. +*/
+Widget toplevel;
+
 /*+ The pane that contains all of the outputs. +*/
 Widget pane;
 
@@ -73,19 +74,19 @@ static int initialising=1;
 
 
 /*++++++++++++++++++++++++++++++++++++++
-  Start the X-Windows part.
+  Start the X-Windows & Athena part.
 
   int *argc The number of command line arguments.
 
   char **argv The actual command line arguments.
   ++++++++++++++++++++++++++++++++++++++*/
 
-void StartX(int *argc,char **argv)
+void Start(int *argc,char **argv)
 {
  Atom close_atom;
- Widget toplevel;
- static char procmeter_version[16]="ProcMeter V" PROCMETER_VERSION;
+ static char procmeter_version[]="ProcMeter V" PROCMETER_VERSION;
  char *string;
+ int i,j=0;
 
  if((string=GetProcMeterRC("resources","horizontal")) &&
     StringToBoolean(string))
@@ -130,6 +131,42 @@ void StartX(int *argc,char **argv)
  XtRealizeWidget(toplevel);
  XFlush(display);
 
+ /* Parse the -w flag */
+
+ for(i=1;i<*argc;i++)
+    if((!strcmp(argv[i],"-w")) && (i+1<=*argc))
+      {
+       char *token;
+
+       i++;j+=2;
+
+       token=strtok(argv[i],",");
+       while(token)
+         {
+          if(!strcmp(token,"above"))
+             add_EWMH("_NET_WM_STATE_ABOVE");
+          else if(!strcmp(token,"below"))
+             add_EWMH("_NET_WM_STATE_BELOW");
+          else if(!strcmp(token,"skip_taskbar"))
+             add_EWMH("_NET_WM_STATE_SKIP_TASKBAR");
+          else if(!strcmp(token,"skip_pager"))
+             add_EWMH("_NET_WM_STATE_SKIP_PAGER");
+          else if(!strcmp(token,"sticky"))
+             add_EWMH("_NET_WM_STATE_STICKY");
+          else
+             fprintf(stderr,"ProcMeter: Cannot parse -w option: '%s'\n",token);
+
+          token = strtok(NULL,",");
+         }
+      }
+
+ if(j>0)
+   {
+    for(i=j;i<*argc;i++)
+      argv[i-j]=argv[i];
+    *argc-=j;
+   }
+
  /* Put an action on the close button */
 
  close_atom=XInternAtom(display,"WM_DELETE_WINDOW",False);
@@ -141,10 +178,10 @@ void StartX(int *argc,char **argv)
 
 
 /*++++++++++++++++++++++++++++++++++++++
-  Stop the X-Windows part.
+  Stop the X-Windows & Athena part.
   ++++++++++++++++++++++++++++++++++++++*/
 
-void StopX(void)
+void Stop(void)
 {
  DestroyMenus();
 
@@ -158,11 +195,21 @@ void StopX(void)
   time_t until The time to sleep until.
   ++++++++++++++++++++++++++++++++++++++*/
 
-void SleepX(time_t until)
+void Sleep(time_t until)
 {
  struct timeval now;
  int delay;
 
+ /* Before we sleep the first time, resize the window. */
+
+ if(initialising)
+   {
+    Resize();
+    initialising=0;
+   }
+
+ /* Sleep */
+
  gettimeofday(&now,NULL);
 
  delay=1000*(until-now.tv_sec)-now.tv_usec/1000;
@@ -190,173 +237,6 @@ void SleepX(time_t until)
 }
 
 
-/*++++++++++++++++++++++++++++++++++++++
-  Perform the updates.
-
-  time_t now The current time.
-  ++++++++++++++++++++++++++++++++++++++*/
-
-void UpdateX(time_t now)
-{
- Module *module;
- Output *output;
- ProcMeterOutput *last=NULL;
-
- for(module=Modules;*module;module++)
-    for(output=(*module)->outputs;*output;output++)
-       if((*output)->output_widget &&
-          (((*output)->output->interval && !(now%(*output)->output->interval)) ||
-          (*output)->first))
-         {
-          if(last!=(*output)->output)
-             if((*module)->Update(now,(*output)->output)==-1)
-                fprintf(stderr,"ProcMeter: Error updating %s.%s\n",(*module)->module->name,(*output)->output->name);
-
-          if((*output)->first)
-             (*output)->first--;
-
-          if(!(*output)->first)
-            {
-             if((*output)->type==PROCMETER_GRAPH)
-               {
-                long value=(*output)->output->graph_value;
-                if(value<0)
-                   value=0;
-                if(value>65535)
-                   value=65535;
-                ProcMeterGraphAddDatum((*output)->output_widget,value);
-               }
-             else if((*output)->type==PROCMETER_TEXT)
-                ProcMeterTextChangeData((*output)->output_widget,(*output)->output->text_value);
-             else if((*output)->type==PROCMETER_BAR)
-               {
-                long value=(*output)->output->graph_value;
-                if(value<0)
-                   value=0;
-                if(value>65535)
-                   value=65535;
-                ProcMeterBarAddDatum((*output)->output_widget,value);
-               }
-            }
-
-          last=(*output)->output;
-         }
-}
-
-
-/*++++++++++++++++++++++++++++++++++++++
-  Add the default outputs at startup.
-
-  int argc The number of command line arguments.
-
-  char **argv The command line arguments.
-  ++++++++++++++++++++++++++++++++++++++*/
-
-void AddDefaultOutputs(int argc,char **argv)
-{
- Output *outputp=NULL;
- Module *modulep=NULL;
- char *string;
- int arg;
-
- if((string=GetProcMeterRC("startup","order")))
-   {
-    char *s=string;
-
-    while(*s && *s==' ')
-       s++;
-
-    while(*s)
-      {
-       int found=0;
-
-       for(modulep=Modules;*modulep;modulep++)
-         {
-          if(!strncmp((*modulep)->module->name,s,strlen((*modulep)->module->name)) &&
-             s[strlen((*modulep)->module->name)]=='.')
-            {
-             for(outputp=(*modulep)->outputs;*outputp;outputp++)
-                if(!strncmp((*outputp)->output->name,&s[strlen((*modulep)->module->name)+1],strlen((*outputp)->output->name)) &&
-                   (s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1]=='-' ||
-                    s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1]==' ' ||
-                    s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1]==0))
-                  {
-                   if((s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1]==' ' ||
-                       s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1]==0) &&
-                      !(*outputp)->output_widget)
-                      AddRemoveOutput(*outputp);
-                   else if(s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+2]=='g' &&
-                           (*outputp)->type==PROCMETER_GRAPH &&
-                           !(*outputp)->output_widget)
-                      AddRemoveOutput(*outputp);
-                   else if(s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+2]=='t' &&
-                           (*outputp)->type==PROCMETER_TEXT &&
-                           !(*outputp)->output_widget)
-                      AddRemoveOutput(*outputp);
-                   else if(s[strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+2]=='b' &&
-                           (*outputp)->type==PROCMETER_BAR &&
-                           !(*outputp)->output_widget)
-                      AddRemoveOutput(*outputp);
-                   found=1;
-                  }
-
-             if(found)
-                break;
-            }
-         }
-
-       while(*s && *s!=' ')
-          s++;
-       while(*s && *s==' ')
-          s++;
-      }
-   }
-
- for(arg=1;arg<argc;arg++)
-   {
-    int found=0;
-
-    for(modulep=Modules;*modulep;modulep++)
-       if(!strncmp((*modulep)->module->name,argv[arg],strlen((*modulep)->module->name)) &&
-          argv[arg][strlen((*modulep)->module->name)]=='.')
-         {
-          for(outputp=(*modulep)->outputs;*outputp;outputp++)
-             if(!strncmp((*outputp)->output->name,&argv[arg][strlen((*modulep)->module->name)+1],strlen((*outputp)->output->name)) &&
-                (argv[arg][strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1]=='-' ||
-                 argv[arg][strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1]==0))
-               {
-                if(!argv[arg][strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+1] &&
-                   !(*outputp)->output_widget)
-                   AddRemoveOutput(*outputp);
-                else if(argv[arg][strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+2]=='g' &&
-                        (*outputp)->type==PROCMETER_GRAPH &&
-                        !(*outputp)->output_widget)
-                   AddRemoveOutput(*outputp);
-                else if(argv[arg][strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+2]=='t' &&
-                        (*outputp)->type==PROCMETER_TEXT &&
-                        !(*outputp)->output_widget)
-                   AddRemoveOutput(*outputp);
-                else if(argv[arg][strlen((*modulep)->module->name)+strlen((*outputp)->output->name)+2]=='b' &&
-                        (*outputp)->type==PROCMETER_BAR &&
-                        !(*outputp)->output_widget)
-                   AddRemoveOutput(*outputp);
-                found=1;
-               }
-
-          if(found)
-             break;
-         }
-
-    if(!*modulep)
-       fprintf(stderr,"ProcMeter: Unrecognised output '%s'\n",argv[arg]);
-   }
-
- initialising=0;
-
- ResizePane();
-}
-
-
 /*++++++++++++++++++++++++++++++++++++++
   Add or remove an output
 
@@ -387,7 +267,7 @@ void AddRemoveOutput(Output output)
  else
    {
     Widget w=NULL;
-    char *string,str[16];
+    char *string,str[PROCMETER_NAME_LEN+1];
     Arg args[16];
     int nargs=0;
     Output *outputp=NULL;
@@ -420,7 +300,11 @@ void AddRemoveOutput(Output output)
     if(((string=GetProcMeterRC2(module->module->name,output->output->name,"label-font")) ||
         (string=GetProcMeterRC(module->module->name,"label-font")) ||
         (string=GetProcMeterRC("resources","label-font"))))
-      {XtSetArg(args[nargs],XtNlabelFont,StringToFont(string));nargs++;}
+      {
+       XFontStruct *font=StringToFont(string);
+       if(font)
+         {XtSetArg(args[nargs],XtNlabelFont,font);nargs++;}
+      }
 
     if(((string=GetProcMeterRC2(module->module->name,output->output->name,"label-foreground")) ||
         (string=GetProcMeterRC(module->module->name,"label-foreground")) ||
@@ -476,7 +360,11 @@ void AddRemoveOutput(Output output)
        if(((string=GetProcMeterRC2(module->module->name,output->output->name,"text-font")) ||
            (string=GetProcMeterRC(module->module->name,"text-font")) ||
            (string=GetProcMeterRC("resources","text-font"))))
-         {XtSetArg(args[nargs],XtNtextFont,StringToFont(string));nargs++;}
+         {
+          XFontStruct *font=StringToFont(string);
+          if(font)
+            {XtSetArg(args[nargs],XtNtextFont,font);nargs++;}
+         }
 
        XtSetArg(args[nargs],XtNlabel,output->label);nargs++;
        XtSetArg(args[nargs],XtNallowResize,True);nargs++;
@@ -529,7 +417,49 @@ void AddRemoveOutput(Output output)
 
  XawPanedSetRefigureMode(pane,True);
 
- ResizePane();
+ Resize();
+}
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Update a graph output.
+
+  Output output The output to update.
+
+  short value The new value.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void UpdateGraph(Output output,short value)
+{
+ ProcMeterGraphAddDatum(output->output_widget,value);
+}
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Update a text output.
+
+  Output output The output to update.
+
+  char *value The new value.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void UpdateText(Output output,char *value)
+{
+ ProcMeterTextChangeData(output->output_widget,value);
+}
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Update a bar output.
+
+  Output output The output to update.
+
+  short value The new value.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void UpdateBar(Output output,short value)
+{
+ ProcMeterBarAddDatum(output->output_widget,value);
 }
 
 
@@ -579,7 +509,7 @@ void MoveOutput(Output output1,Output output2,int direction)
 
  XawPanedSetRefigureMode(pane,True);
 
- ResizePane();
+ Resize();
 
  if(direction==1 && i2>i1)
    {
@@ -608,49 +538,13 @@ void MoveOutput(Output output1,Output output2,int direction)
 }
 
 
-/*++++++++++++++++++++++++++++++++++++++
-  The function called by the timeout to terminate the sleep.
-
-  XtPointer p Not used.
-
-  XtIntervalId i Not used.
-
-  This function is only ever called from the Xt Intrinsics routines.
-  ++++++++++++++++++++++++++++++++++++++*/
-
-static void SleepCallback(XtPointer p,XtIntervalId i)
-{
- sleeping=0;
-}
-
-
-/*++++++++++++++++++++++++++++++++++++++
-  A callback that is activated by a resize event on the parent pane.
-
-  Widget w The widget that caused the callback.
-
-  XtPointer va Not used.
-
-  XEvent* e The event that requires action.
-
-  Boolean* vb Not used.
-
-  This function is only ever called from the Xt Intrinsics routines.
-  ++++++++++++++++++++++++++++++++++++++*/
-
-static void ResizePaneCallback(Widget w,XtPointer va,XEvent* e,Boolean* vb)
-{
- ResizePane();
-}
-
-
 /*++++++++++++++++++++++++++++++++++++++
   Resize the pane.
   ++++++++++++++++++++++++++++++++++++++*/
 
-static void ResizePane(void)
+void Resize(void)
 {
- Dimension psize,size;
+ Dimension psize;
  int gsize,msize;
  int i,ngraphs=0;
 
@@ -692,6 +586,8 @@ static void ResizePane(void)
 
  for(i=0;i<ndisplayed;i++)
    {
+    Dimension size;
+
     if(displayed[i]->type==PROCMETER_GRAPH || displayed[i]->type==PROCMETER_BAR)
       {
        size=gsize/ngraphs;
@@ -708,6 +604,42 @@ static void ResizePane(void)
 }
 
 
+/*++++++++++++++++++++++++++++++++++++++
+  The function called by the timeout to terminate the sleep.
+
+  XtPointer p Not used.
+
+  XtIntervalId i Not used.
+
+  This function is only ever called from the Xt Intrinsics routines.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+static void SleepCallback(XtPointer p,XtIntervalId i)
+{
+ sleeping=0;
+}
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  A callback that is activated by a resize event on the parent pane.
+
+  Widget w The widget that caused the callback.
+
+  XtPointer va Not used.
+
+  XEvent* e The event that requires action.
+
+  Boolean* vb Not used.
+
+  This function is only ever called from the Xt Intrinsics routines.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+static void ResizePaneCallback(Widget w,XtPointer va,XEvent* e,Boolean* vb)
+{
+ Resize();
+}
+
+
 /*++++++++++++++++++++++++++++++++++++++
   A callback that is activated by a close window event on the toplevel window.
 
@@ -735,3 +667,29 @@ static void CloseCallback(Widget w,XtPointer va,XEvent* e,Boolean* vb)
        quit=1;
    }
 }
+
+
+/*++++++++++++++++++++++++++++++++++++++
+  Adds an Extended Window Manager Hint to the window.
+
+  char *name The name of the hint to add.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+static void add_EWMH(char *name)
+{
+ XEvent event;
+
+ event.xclient.type=ClientMessage;
+ event.xclient.serial=0;
+ event.xclient.send_event=True;
+ event.xclient.message_type=XInternAtom(display,"_NET_WM_STATE",False);
+ event.xclient.window=XtWindow(toplevel);
+ event.xclient.format=32;
+ event.xclient.data.l[0]=1; /* add */
+ event.xclient.data.l[1]=XInternAtom(display,name,False);
+ event.xclient.data.l[2]=0;
+ event.xclient.data.l[3]=0;
+ event.xclient.data.l[4]=0;
+
+ XSendEvent(display,DefaultRootWindow(display),False,SubstructureRedirectMask|SubstructureNotifyMask,&event);
+}
